# [Django Theme Pixel](https://appseed.us/product/pixel-bootstrap/django/)

Modern Theme for **Django** that covers authentication pages (registration included) crafted on top of **[Pixel Bootstrap 5](https://appseed.us/product/pixel-bootstrap/django/)**, an open-source `Bootstrap` design from `Themesberg`.

> Actively supported by [AppSeed](https://appseed.us/) via `Email` and `Discord`.

<br>

**Links & Resources**

- [Django Pixel Bootstrap 5](https://appseed.us/product/pixel-bootstrap/django/) - `Product page`
  - `Features`: Fully-configured, `CI/CD` via Render
- UI Kit: `Pixel Lite` (Bootstrap 5) by Themesberg
- **Sections Covered**: 
  - `All pages` managed by `Django.contrib.AUTH`
  - `Registration` page
  - `Misc pages`: colors, icons, typography, blank-page 
  
<br />

![Pixel Bootstrap Lite - Full-Stack Starter generated by AppSeed.](https://user-images.githubusercontent.com/51070104/168753915-d61b2f97-57b2-4d14-a774-d217d120ff62.png)

<br />

## Why `Django Pixel Lite`

- Modern [Bootstrap 5](https://www.admin-dashboards.com/bootstrap-5-templates/) Design
- `Minimal Template` overriding
- `Easy integration`
- Fully compatible with `Django.contrib.AUTH`
- `Registration` page included

<br />

## How to use it

<br />

> **Install the package** via `PIP` 

```bash
$ pip install django-theme-pixel
// OR
$ pip install git+https://github.com/app-generator/django-theme-pixel.git
```

<br />

> Add `theme_pixel` application to the `INSTALLED_APPS` setting of your Django project `settings.py`:

```python
INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.staticfiles",

    'theme_pixel',          # <-- NEW 
]
```

<br />

> Update project `settings.py` file to include (at the end of the file):

```python
LOGIN_REDIRECT_URL = '/'
EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'
```

<br />

> Add `theme_pixel` urls in your Django Project `urls.py` file.

```python
from django.urls import path, include       # <-- UPD with 'include' directive

urlpatterns = [
    ...
    path('', include('theme_pixel.urls')),  #  <-- NEW
]
```

<br />

> **Collect static** if you are in `production environment`:

```bash
$ python manage.py collectstatic
```

<br />

> **Start the app**

```bash
$ # Set up the database
$ python manage.py makemigrations
$ python manage.py migrate
$
$ # Create the superuser
$ python manage.py createsuperuser
$
$ # Start the application (development mode)
$ python manage.py runserver # default port 8000
```

<br />

## [PRO Version](https://appseed.us/product/pixel-bootstrap-pro/django)   

Seed project powered by **Django** Framework on top of **Pixel PRO** design. `Pixel` is a premium [Bootstrap 5](https://www.admin-dashboards.com/bootstrap-5-templates/) UI Kit featuring over 200 fully coded UI elements and example pages that will help you prototype and build a website for your next project.

![Pixel Bootstrap PRO - Full-Stack Starter generated by AppSeed](https://user-images.githubusercontent.com/51070104/168760719-f0e45406-2b2a-43e0-badf-fa953edb62b8.png)

<br />

---
**[Django Theme Pixel](https://appseed.us/product/pixel-bootstrap/django/)** - Modern Theme provided by **[AppSeed](https://appseed.us/)**
